<template>
  <AuthLayout>
    <AlertInfo>
      {{ $t("app.auth.forgot_password.info") }}
    </AlertInfo>
    <FormGroup @submit="submit">
      <AlertError v-if="form.errors && form.errors?.unknown">
        {{ form.errors.unknown }}
      </AlertError>
      <FormInput
        id="email"
        :errors="form.errors.email"
      >
        <FormLabel>{{ $t("app.auth.forgot_password.form.email") }}</FormLabel>
        <FormText
          v-model="form.values.email"
          autocomplete="email"
          name="email"
          required
          type="email"
        />
      </FormInput>
      <div>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-primary w-full"
        >
          {{ $t("app.auth.forgot_password.form.submit") }}
        </FormSubmit>
      </div>
    </FormGroup>
    <div>
      <RouterLink
        :to="{ name: 'login' }"
        class="btn btn-white flex w-full justify-center"
      >
        {{ $t("app.auth.forgot_password.login") }}
      </RouterLink>
    </div>
  </AuthLayout>
</template>

<script lang="ts" setup>
import AuthLayout from "@/js/contexts/auth/ui/layouts/AuthLayout.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormGroup from "@/js/contexts/form/ui/components/FormGroup.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import AlertInfo from "@/js/contexts/shared/ui/components/alert/AlertInfo.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";

const { t } = useI18n();
const router = useRouter();
const { successNotification } = useNotification();

useHead({
  title: t("app.auth.forgot_password.title"),
});

const form = useForm({
  email: "",
});

const submit = () => {
  form.post("/forgot-password", {
    onError: () => form.reset("email"),
    onSuccess: () => {
      successNotification(t("app.auth.forgot_password.success"));
      router.push({ name: "login" });
    },
  });
};
</script>
